==> am_mod_grp_0_1.tar.gz: am_mod_grp_0_1/components/grp/template/barnraiser_01/overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index');" />
			</span>
			
			<?php echo $lang['hdr_latest_groups'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_ties');" />
			</span>
			
			<?php echo $lang['hdr_tied_subjects'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_subjects)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tied_subjects as $key => $i):
				?>
				<tr>
					<td valign="top" colspan="3">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;group_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
					</td>
				</tr>
				<tr>
					<td width="32">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;group_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity_id_relation'];?>"><img src="get_file.php?file=<?php echo $i['identity']['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['identity']['image']['file_title'];?>" /></a><br />
					</td>
					<?php
					if (!empty($i['revision'])) {
					?>
					<td valign="top">
						<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['item_id'];?>&amp;subject_id=<?php echo $i['subject']['subject_id'];?>"><?php echo $i['subject']['subject_title'];?></a><br />
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['subject']['subject_create_datetime'],1);?><br />
					</td>
					<?php
					}
					else {
					?>
					<td colspan="2" valign="top">
						<?php echo $lang['err_no_tied_revisions'];?><br />
					</td>
					<?php }?>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_tied_subjects'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index#subjects');" />
			</span>
			
			<?php echo $lang['hdr_latest_subjects'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $i['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>					
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index#my_groups');" />
			</span>
			
			<?php echo $lang['hdr_my_groups'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($my_groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($my_groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['err_no_my_groups'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" />
			</span>
			
			<?php echo $lang['hdr_favourites'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php
					if (isset($my_bookmarks)) {
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
					<?php
					endforeach;
					} else {
					?>
						<p>
							<?php
							$lang['err_no_bookmarks'] = str_replace('SYS_KEYWORD_ICON', "<img src='" . $template_path_core . "img/mark.png' />", $lang['err_no_bookmarks']);
							echo $lang['err_no_bookmarks'];
							?><br />
						</p>
					<?php }?>
				</p>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_ties');" />
			</span>
			
			<?php echo $lang['hdr_tied_comments'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_comments)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($tied_comments as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['item_id'];?>&amp;subject_id=<?php echo $i['inner_item_id'];?>#comment_id<?php echo $i['comment_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
						<?php echo $i['comment_body'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['comment_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_tied_comments'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

==> am_mod_grp_0_3.tar.gz: am_mod_grp_0_3/components/grp/template/barnraiser_01/overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_latest_groups'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_ties');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_tied_subjects'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($respected_published_subjects)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($respected_published_subjects as $key => $i):
				?>
				<tr>
					<td valign="top" colspan="3">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;group_id=<?php echo $i['group_id'];?>&amp;identity_id=<?php echo $i['identity_id'];?>"><b><?php echo $i['identity_nic'];?></b></a><br />
					</td>
				</tr>
				<tr>
					<td width="32">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;group_id=<?php echo $i['group_id'];?>&amp;identity_id=<?php echo $i['identity_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
					</td>
					<td valign="top">
						<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['subject_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_tied_subjects'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index#subjects');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_latest_subjects'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($subjects)) {
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php
					foreach ($subjects as $key => $i):
					?>
					<tr>
						<td valign="middle" width="32">	
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
						</td>
						<td valign="top">
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
							<?php echo $i['subject_synopsis'];?><br />
						</td>
						<td valign="top" align="center">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>&amp;group_id=<?php echo $i['group_id'];?>">
							<?php echo $i['identity']['identity_nic'];?></a><br />
							<?php echo $this->date->formatDate($i['subject_create_datetime'], 1);?><br />				
						</td>
						<td valign="top" align="center">
							<?php echo $i['total_comments'];?>&nbsp;replies<br />
							
							<?php
							if (!empty($i['latest_comment'])) {
							?>
							<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>#comment_body_id_<?php echo $i['latest_comment'][0]['comment_id'];?>">latest</a><br />
							<?php echo $this->date->formatDate($i['latest_comment'][0]['comment_create_datetime'], 1);?><br />
							<?php }?>
						</td>
						<td valign="top">
							<?php
							if (!empty($i['subject_locked'])) {
							?>
								<img src="<?php echo $template_path;?>img/locked.png" vspace="2" alt="<?php echo $lang['txt_alt_locked'];?>" border="0" title="<?php echo $lang['txt_locked'];?>" /><br />
							<?php }?>
								
							<?php
							if (!empty($i['subject_sticky'])) {
							?>
								<img src="<?php echo $template_path;?>img/sticky.png" vspace="2" alt="<?php echo $lang['txt_alt_sticky'];?>" border="0" title="<?php echo $lang['txt_sticky'];?>" /><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td colspan="5">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_index#my_groups');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_my_groups'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($my_groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($my_groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['err_no_my_groups'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_favourites'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php
					if (isset($my_bookmarks)) {
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
					<?php
					endforeach;
					} else {
					?>
						<p>
							<?php
							$lang['err_no_bookmarks'] = str_replace('SYS_KEYWORD_ICON', "<img src='" . $template_path_core . "img/mark.png' />", $lang['err_no_bookmarks']);
							echo $lang['err_no_bookmarks'];
							?><br />
						</p>
					<?php }?>
				</p>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_tied_comments'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($respected_published_comments)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($respected_published_comments as $key => $i):
				?>
				<tr>
					<td valign="top" colspan="3">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity_id'];?>"><b><?php echo $i['identity_nic'];?></b></a><br />
					</td>
				</tr>
				<tr>
					<td width="32">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
					</td>
					<td valign="top">
						<?php echo $i['comment_body'];?><br />
					</td>
					<td align="right" valign="top">
						<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['item_id'];?>&amp;subject_id=<?php echo $i['inner_item_id'];?>"><?php echo $this->date->formatDate($i['comment_create_datetime'],1);?></a><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['err_no_tied_comments'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>
